pub struct TemplateContext<'a> {
pub krate: &'a str,
pub krate_version: &'a str,
pub target: TargetType,
pub repository: Option<&'a str>,
pub repository_host: Option<String>,
pub license: Option<&'a str>,
pub rust_version: Option<&'a Version>,
pub readme: String,
pub links: String,
}Expand description
This struct documents all available placeholders in the readme template.
Fields
krate: &'a strThe name of the crate.
This is renamed to crate for the template, do not use {{ krate }},
it won’t work.
krate_version: &'a strThe version of the crate.
This is renamed to crate_version for the template, do not use {{ krate_version }},
it won’t work.
target: TargetTypeThe target type, etiher bin or lib.
repository: Option<&'a str>The repository variable from the Cargo.toml file, if set.
repository_host: Option<String>The HTTP(S) host name of the repository variable, if set. This can be used to
add a Codeberg icon if the code is hosted on Codeberg, for example.
license: Option<&'a str>The license variable from the Cargo.toml file, if set. Note that in case only
the license-file variable is set, this will be none.
rust_version: Option<&'a Version>The rust_version variable from the Cargo.toml file, interpreted as a semver
Version. This means that, if the Cargo.toml specifies 1.90, this variable
will read 1.90.0.
readme: StringThe main content of the readme. Every template should contain this variable exactly once. Place it whever it is convenient.
links: StringThe links section of the readme. Place this at the bottom of the readme. You may omit this if it is empty.